Buscar

GREP
Si quieres buscar un texto dentro de un archivo en una ruta:
-R: Recursivo.
-i: No distingue mayúsculas de minúsculas.
grep -Ri 'ALGO' DONDE
Cuando lo tengas localizado para verlo mejor:
grep -i 'ALGO' '*.log'
FIND
Para buscar un archivo:
-type f: Fichero.
-type d: Carpeta.
find / -type f -iname 'ALGO' 2>/dev/null
Para buscar un archivo y ejecutar una segunda consulta:
-iname: Buscar algo y no distingue mayúsculas de minúsculas.
-mtime: Tiempo a buscar o desde cuando (-X: Menos de, a partir de // +X: Más de, antes de)
-exec: Ejecutar lo siguiente.
find RUTA(si no se pone, es la actual) -type f -iname 'ALGO*' -mtime +X -exec ls -lrt {} \;
Buscar en ZIP
Usando grep:
zgrep -i 'ALGO' FICHERO
Usando cat:
zcat FICHERO | grep -i 'ALGO'
Buscar programas instalados
Restringe sus búsquedas a las rutas definidas en la variable de entorno PATH, usando whereis o which:
whereis 'ALGO'
which 'ALGO'
Si los binarios que buscamos no están en el PATH, podríamos usar:
find / -executable -type f -iname 'ALGO'